@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone 
+ * This file is part of Liblinphone
  * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 
 // =============================================================================
 
-typedef enum _LinphoneChatMessageDir{
+typedef enum _LinphoneChatMessageDir {
 	LinphoneChatMessageIncoming,
 	LinphoneChatMessageOutgoing
 } LinphoneChatMessageDir;
@@ -34,7 +34,7 @@ typedef enum _LinphoneChatMessageDir{
 // =============================================================================
 
 #ifdef __cplusplus
-	extern "C" {
+extern "C" {
 #endif // ifdef __cplusplus
 
 /**
@@ -47,27 +47,27 @@ typedef enum _LinphoneChatMessageDir{
  * @param message #LinphoneChatMessage object. @notnil
  * @return The same #LinphoneChatMessage object. @notnil
  */
-LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_message_ref (LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_message_ref(LinphoneChatMessage *message);
 
 /**
  * Release reference to the chat message.
  * @param message #LinphoneChatMessage object. @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_unref (LinphoneChatMessage *message);
+LINPHONE_PUBLIC void linphone_chat_message_unref(LinphoneChatMessage *message);
 
 /**
  * Retrieve the user pointer associated with the chat message.
  * @param message #LinphoneChatMessage object. @notnil
  * @return The user pointer associated with the chat message. @maybenil
  */
-LINPHONE_PUBLIC void *linphone_chat_message_get_user_data (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC void *linphone_chat_message_get_user_data(const LinphoneChatMessage *message);
 
 /**
  * Assign a user pointer to the chat message.
  * @param message #LinphoneChatMessage object. @notnil
  * @param user_data The user pointer to associate with the chat message. @maybenil
  */
-LINPHONE_PUBLIC void linphone_chat_message_set_user_data (LinphoneChatMessage *message, void *user_data);
+LINPHONE_PUBLIC void linphone_chat_message_set_user_data(LinphoneChatMessage *message, void *user_data);
 
 // =============================================================================
 
@@ -75,15 +75,15 @@ LINPHONE_PUBLIC void linphone_chat_message_set_user_data (LinphoneChatMessage *m
  * Returns back pointer to #LinphoneCore object.
  * @param message #LinphoneChatMessage object. @notnil
  * @return the #LinphoneCore object associated with this message. @notnil
-**/
-LINPHONE_PUBLIC LinphoneCore *linphone_chat_message_get_core (const LinphoneChatMessage *message);
+ **/
+LINPHONE_PUBLIC LinphoneCore *linphone_chat_message_get_core(const LinphoneChatMessage *message);
 
 /**
  * Linphone message can carry external body as defined by rfc2017
  * @param message #LinphoneChatMessage object. @notnil
  * @return external body url or NULL if not present. @maybenil
  */
-LINPHONE_PUBLIC const char *linphone_chat_message_get_external_body_url (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_external_body_url(const LinphoneChatMessage *message);
 
 /**
  * Linphone message can carry external body as defined by rfc2017
@@ -91,42 +91,43 @@ LINPHONE_PUBLIC const char *linphone_chat_message_get_external_body_url (const L
  * @param message #LinphoneChatMessage object. @notnil
  * @param external_body_url ex: access-type=URL; URL="http://www.foo.com/file" @maybenil
  */
-LINPHONE_PUBLIC void linphone_chat_message_set_external_body_url (LinphoneChatMessage *message, const char *external_body_url);
+LINPHONE_PUBLIC void linphone_chat_message_set_external_body_url(LinphoneChatMessage *message,
+                                                                 const char *external_body_url);
 
 /**
  * Get the time the message was sent.
  * @param message #LinphoneChatMessage object. @notnil
  * @return the timestamp of when the message was sent.
  */
-LINPHONE_PUBLIC time_t linphone_chat_message_get_time (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC time_t linphone_chat_message_get_time(const LinphoneChatMessage *message);
 
 /**
  * Returns wehther the message has been sent or received.
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if message has been sent, FALSE if it has been received.
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_is_outgoing (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_is_outgoing(const LinphoneChatMessage *message);
 
 /**
  * Get origin of the message
  * @param message #LinphoneChatMessage object. @notnil
  * @return the #LinphoneAddress of the sender. @notnil
  */
-LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_from_address (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_from_address(const LinphoneChatMessage *message);
 
 /**
  * Get destination of the message
  * @param message #LinphoneChatMessage object. @notnil
  * @return the #LinphoneAddress of the recipient. @notnil
  */
-LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_to_address (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_to_address(const LinphoneChatMessage *message);
 
 /**
  * Get the content type of a chat message.
  * @param message #LinphoneChatMessage object. @notnil
  * @return The content type of the chat message @notnil
  */
-LINPHONE_PUBLIC const char *linphone_chat_message_get_content_type (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_content_type(const LinphoneChatMessage *message);
 
 /**
  * Set the content type of a chat message.
@@ -134,14 +135,14 @@ LINPHONE_PUBLIC const char *linphone_chat_message_get_content_type (const Linpho
  * @param message #LinphoneChatMessage object. @notnil
  * @param content_type The new content type of the chat message @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_set_content_type (LinphoneChatMessage *message, const char *content_type);
+LINPHONE_PUBLIC void linphone_chat_message_set_content_type(LinphoneChatMessage *message, const char *content_type);
 
 /**
  * Get text part of this message. Introduced in 01/07/2020
  * @param message #LinphoneChatMessage object. @notnil
  * @return The text in UTF8 or NULL if no text. @maybenil
  */
-LINPHONE_PUBLIC const char *linphone_chat_message_get_utf8_text (const LinphoneChatMessage* message);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_utf8_text(const LinphoneChatMessage *message);
 
 /**
  * Set a chat message text to be sent by linphone_chat_room_send_message(). Introduced in 01/07/2020
@@ -149,7 +150,7 @@ LINPHONE_PUBLIC const char *linphone_chat_message_get_utf8_text (const LinphoneC
  * @param text The text in UTF8 to set. @maybenil
  * @return 0 if succeed.
  */
-LINPHONE_PUBLIC int linphone_chat_message_set_utf8_text(LinphoneChatMessage *message , const char* text);
+LINPHONE_PUBLIC int linphone_chat_message_set_utf8_text(LinphoneChatMessage *message, const char *text);
 
 /**
  * Get the message identifier.
@@ -157,7 +158,7 @@ LINPHONE_PUBLIC int linphone_chat_message_set_utf8_text(LinphoneChatMessage *mes
  * @param message #LinphoneChatMessage object. @notnil
  * @return The message identifier. @notnil
  */
-LINPHONE_PUBLIC const char *linphone_chat_message_get_message_id (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_message_id(const LinphoneChatMessage *message);
 
 /**
  * Linphone message has an app-specific field that can store a text. The application might want
@@ -165,7 +166,7 @@ LINPHONE_PUBLIC const char *linphone_chat_message_get_message_id (const Linphone
  * @param message #LinphoneChatMessage object. @notnil
  * @return the application-specific data or NULL if none has been stored. @maybenil
  */
-LINPHONE_PUBLIC const char *linphone_chat_message_get_appdata (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_appdata(const LinphoneChatMessage *message);
 
 /**
  * Linphone message has an app-specific field that can store a text. The application might want
@@ -177,14 +178,14 @@ LINPHONE_PUBLIC const char *linphone_chat_message_get_appdata (const LinphoneCha
  * @param message #LinphoneChatMessage object. @notnil
  * @param data the data to store into the message. @maybenil
  */
-LINPHONE_PUBLIC void linphone_chat_message_set_appdata (LinphoneChatMessage *message, const char *data);
+LINPHONE_PUBLIC void linphone_chat_message_set_appdata(LinphoneChatMessage *message, const char *data);
 
 /**
  * Returns the chatroom this message belongs to.
  * @param message #LinphoneChatMessage object. @notnil
  * @return the #LinphoneChatRoom in which this message has been sent or received. @notnil
  */
-LINPHONE_PUBLIC LinphoneChatRoom *linphone_chat_message_get_chat_room (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneChatRoom *linphone_chat_message_get_chat_room(const LinphoneChatMessage *message);
 
 // =============================================================================
 
@@ -193,7 +194,7 @@ LINPHONE_PUBLIC LinphoneChatRoom *linphone_chat_message_get_chat_room (const Lin
  * @param message #LinphoneChatMessage object. @notnil
  * @return Whether or not the message is to be stored
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_get_to_be_stored (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_get_to_be_stored(const LinphoneChatMessage *message);
 
 /**
  * Set if a chat message is to be stored.
@@ -201,23 +202,23 @@ LINPHONE_PUBLIC bool_t linphone_chat_message_get_to_be_stored (const LinphoneCha
  * @param message #LinphoneChatMessage object. @notnil
  * @param to_be_stored Whether or not the chat message is to be stored
  */
-LINPHONE_PUBLIC void linphone_chat_message_set_to_be_stored (LinphoneChatMessage *message, bool_t to_be_stored);
+LINPHONE_PUBLIC void linphone_chat_message_set_to_be_stored(LinphoneChatMessage *message, bool_t to_be_stored);
 
-LINPHONE_PUBLIC unsigned int linphone_chat_message_store (LinphoneChatMessage *message);
+LINPHONE_PUBLIC unsigned int linphone_chat_message_store(LinphoneChatMessage *message);
 
 /**
  * Get the state of the message
  * @param message #LinphoneChatMessage object. @notnil
  * @return the current #LinphoneChatMessageState of the message.
  */
-LINPHONE_PUBLIC LinphoneChatMessageState linphone_chat_message_get_state (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneChatMessageState linphone_chat_message_get_state(const LinphoneChatMessage *message);
 
 /**
  * Get if the message was encrypted when transfered
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if the message was encrypted when transfered, FALSE otherwise.
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_is_secured (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_is_secured(const LinphoneChatMessage *message);
 
 /**
  * Get the file_transfer_information (used by call backs to recover informations during a rcs file transfer)
@@ -225,12 +226,14 @@ LINPHONE_PUBLIC bool_t linphone_chat_message_is_secured (const LinphoneChatMessa
  * @param message #LinphoneChatMessage object. @notnil
  * @return a pointer to the #LinphoneContent structure or NULL if not present. @maybenil
  */
-LINPHONE_PUBLIC LinphoneContent *linphone_chat_message_get_file_transfer_information (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneContent *
+linphone_chat_message_get_file_transfer_information(const LinphoneChatMessage *message);
 
 /**
  * Start the download of the #LinphoneContent referenced in the #LinphoneChatMessage from remote server.
  * @param message #LinphoneChatMessage object. @notnil
- * @param content the #LinphoneContent object to download (must have the linphone_content_is_file_transfer() method return TRUE). @notnil
+ * @param content the #LinphoneContent object to download (must have the linphone_content_is_file_transfer() method
+ * return TRUE). @notnil
  * @return FALSE if there is an error, TRUE otherwise.
  */
 LINPHONE_PUBLIC bool_t linphone_chat_message_download_content(LinphoneChatMessage *message, LinphoneContent *content);
@@ -239,22 +242,22 @@ LINPHONE_PUBLIC bool_t linphone_chat_message_download_content(LinphoneChatMessag
  * Cancel an ongoing file transfer attached to this message.(upload or download)
  * @param message #LinphoneChatMessage object. @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_cancel_file_transfer (LinphoneChatMessage *message);
+LINPHONE_PUBLIC void linphone_chat_message_cancel_file_transfer(LinphoneChatMessage *message);
 
 /**
  * Send a chat message.
  * @param message #LinphoneChatMessage object. @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_send (LinphoneChatMessage *message);
+LINPHONE_PUBLIC void linphone_chat_message_send(LinphoneChatMessage *message);
 
-LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_peer_address (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_peer_address(const LinphoneChatMessage *message);
 
 /**
  * Returns the local address the message was sent or received with.
  * @param message #LinphoneChatMessage object. @notnil
  * @return the #LinphoneAddress of the local address used to send/receive this message. @notnil
  */
-LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_local_address (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_local_address(const LinphoneChatMessage *message);
 
 /**
  * Add custom headers to the message.
@@ -262,11 +265,9 @@ LINPHONE_PUBLIC const LinphoneAddress *linphone_chat_message_get_local_address (
  * @param header_name name of the header @notnil
  * @param header_value header value @maybenil
  */
-LINPHONE_PUBLIC void linphone_chat_message_add_custom_header (
-	LinphoneChatMessage *message,
-	const char *header_name,
-	const char *header_value
-);
+LINPHONE_PUBLIC void linphone_chat_message_add_custom_header(LinphoneChatMessage *message,
+                                                             const char *header_name,
+                                                             const char *header_value);
 
 /**
  * Retrieve a custom header value given its name.
@@ -274,72 +275,74 @@ LINPHONE_PUBLIC void linphone_chat_message_add_custom_header (
  * @param header_name header name searched @notnil
  * @return the custom header value or NULL if not found. @maybenil
  */
-LINPHONE_PUBLIC const char * linphone_chat_message_get_custom_header (const LinphoneChatMessage *message, const char *header_name);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_custom_header(const LinphoneChatMessage *message,
+                                                                    const char *header_name);
 
 /**
  * Removes a custom header from the message.
  * @param message #LinphoneChatMessage object. @notnil
  * @param header_name name of the header to remove @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_remove_custom_header (LinphoneChatMessage *message, const char *header_name);
+LINPHONE_PUBLIC void linphone_chat_message_remove_custom_header(LinphoneChatMessage *message, const char *header_name);
 
 /**
  * Returns wether the message has been read or not.
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if message has been marked as read, FALSE otherwise.
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_is_read (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_is_read(const LinphoneChatMessage *message);
 
-LINPHONE_PUBLIC LinphoneReason linphone_chat_message_get_reason (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneReason linphone_chat_message_get_reason(const LinphoneChatMessage *message);
 
 /**
  * Get full details about delivery error of a chat message.
  * @param message #LinphoneChatMessage object. @notnil
  * @return a #LinphoneErrorInfo describing the details. @notnil
  */
-LINPHONE_PUBLIC const LinphoneErrorInfo *linphone_chat_message_get_error_info (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const LinphoneErrorInfo *linphone_chat_message_get_error_info(const LinphoneChatMessage *message);
 
 /**
  * Returns wether the chat message is a forward message or not.
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if it is a forward message, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_is_forward (LinphoneChatMessage *message);
-		
+LINPHONE_PUBLIC bool_t linphone_chat_message_is_forward(LinphoneChatMessage *message);
+
 /**
  * Gets the forward info if available as a string
  * @param message #LinphoneChatMessage object. @notnil
  * @return the original sender of the message if it has been forwarded, NULL otherwise. @maybenil
  */
-LINPHONE_PUBLIC const char *linphone_chat_message_get_forward_info (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_forward_info(const LinphoneChatMessage *message);
 
 /**
  * Returns wether the chat message is a reply message or not.
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if it is a reply message, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_is_reply (LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_is_reply(LinphoneChatMessage *message);
 
 /**
  * Returns the ID of the message this is a reply to.
  * @param message #LinphoneChatMessage object. @notnil
  * @return the original message id. @maybenil
  */
-LINPHONE_PUBLIC const char* linphone_chat_message_get_reply_message_id(LinphoneChatMessage *message);
+LINPHONE_PUBLIC const char *linphone_chat_message_get_reply_message_id(LinphoneChatMessage *message);
 
 /**
- * Returns the ID of the message this is a reply to.
+ * Returns the address of the sender of the message this is a reply to.
  * @param message #LinphoneChatMessage object. @notnil
  * @return the original message sender #LinphoneAddress. @maybenil
  */
-const LINPHONE_PUBLIC LinphoneAddress* linphone_chat_message_get_reply_message_sender_address(LinphoneChatMessage *message);
+const LINPHONE_PUBLIC LinphoneAddress *
+linphone_chat_message_get_reply_message_sender_address(LinphoneChatMessage *message);
 
 /**
  * Returns the #LinphoneChatMessage this message is a reply to.
  * @param message #LinphoneChatMessage object. @notnil
  * @return the original message #LinphoneChatMessage. @maybenil
  */
-LINPHONE_PUBLIC LinphoneChatMessage* linphone_chat_message_get_reply_message(LinphoneChatMessage *message);
+LINPHONE_PUBLIC LinphoneChatMessage *linphone_chat_message_get_reply_message(LinphoneChatMessage *message);
 
 /**
  * Returns wether the chat message is an ephemeral message or not.
@@ -356,7 +359,7 @@ LINPHONE_PUBLIC bool_t linphone_chat_message_is_ephemeral(const LinphoneChatMess
  * @param message #LinphoneChatMessage object. @notnil
  * @return the lifetime of an ephemeral message, by default 0 (disabled).
  */
-LINPHONE_PUBLIC long linphone_chat_message_get_ephemeral_lifetime (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC long linphone_chat_message_get_ephemeral_lifetime(const LinphoneChatMessage *message);
 
 /**
  * Returns the real time at which an ephemeral message expires and will be deleted.
@@ -364,17 +367,17 @@ LINPHONE_PUBLIC long linphone_chat_message_get_ephemeral_lifetime (const Linphon
  * @param message #LinphoneChatMessage object. @notnil
  * @return the time at which an ephemeral message expires. 0 means the message has not been read.
  */
-LINPHONE_PUBLIC time_t linphone_chat_message_get_ephemeral_expire_time (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC time_t linphone_chat_message_get_ephemeral_expire_time(const LinphoneChatMessage *message);
 
 /**
- * Fulfill a chat message char by char. 
+ * Fulfill a chat message char by char.
  * Message linked to a Real Time Text Call send char in realtime following RFC 4103/T.140
  * To commit a message, use linphone_chat_room_send_message()
  * @param message #LinphoneChatMessage object. @notnil
  * @param character T.140 char
  * @return 0 if succeed.
  */
-LINPHONE_PUBLIC LinphoneStatus linphone_chat_message_put_char (LinphoneChatMessage *message, uint32_t character);
+LINPHONE_PUBLIC LinphoneStatus linphone_chat_message_put_char(LinphoneChatMessage *message, uint32_t character);
 
 /**
  * Add a listener in order to be notified of #LinphoneChatMessage events.
@@ -392,7 +395,8 @@ LINPHONE_PUBLIC void linphone_chat_message_remove_callbacks(LinphoneChatMessage
 
 /**
  * Gets the current LinphoneChatMessageCbs.
- * This is meant only to be called from a callback to be able to get the user_data associated with the #LinphoneChatMessageCbs that is calling the callback.
+ * This is meant only to be called from a callback to be able to get the user_data associated with the
+ * #LinphoneChatMessageCbs that is calling the callback.
  * @param message #LinphoneChatMessage object @notnil
  * @return The #LinphoneChatMessageCbs that has called the last callback. @maybenil
  */
@@ -403,28 +407,28 @@ LINPHONE_PUBLIC LinphoneChatMessageCbs *linphone_chat_message_get_current_callba
  * @param message #LinphoneChatMessage object. @notnil
  * @param content the #LinphoneContent object to add. @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_add_file_content (LinphoneChatMessage *message, LinphoneContent *content);
+LINPHONE_PUBLIC void linphone_chat_message_add_file_content(LinphoneChatMessage *message, LinphoneContent *content);
 
 /**
  * Creates a #LinphoneContent of type PlainText with the given text as body. Introduced in 01/07/2020
  * @param message #LinphoneChatMessage object. @notnil
  * @param text The text in UTF8 to add to the message. @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_add_utf8_text_content (LinphoneChatMessage *message, const char *text);
+LINPHONE_PUBLIC void linphone_chat_message_add_utf8_text_content(LinphoneChatMessage *message, const char *text);
 
 /**
  * Adds a content to the ChatMessage.
  * @param message #LinphoneChatMessage object. @notnil
  * @param content the #LinphoneContent object to add. @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_add_content (LinphoneChatMessage *message, LinphoneContent *content);
+LINPHONE_PUBLIC void linphone_chat_message_add_content(LinphoneChatMessage *message, LinphoneContent *content);
 
 /**
  * Removes a content from the ChatMessage.
  * @param message #LinphoneChatMessage object. @notnil
  * @param content the #LinphoneContent object to remove. @notnil
  */
-LINPHONE_PUBLIC void linphone_chat_message_remove_content (LinphoneChatMessage *message, LinphoneContent *content);
+LINPHONE_PUBLIC void linphone_chat_message_remove_content(LinphoneChatMessage *message, LinphoneContent *content);
 
 /**
  * Returns the list of contents in the message.
@@ -438,19 +442,18 @@ LINPHONE_PUBLIC const bctbx_list_t *linphone_chat_message_get_contents(const Lin
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if download or upload is in progress, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_is_file_transfer_in_progress (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_is_file_transfer_in_progress(const LinphoneChatMessage *message);
 
 /**
- * Gets the list of participants for which the imdn state has reached the specified state and the time at which they did.
+ * Gets the list of participants for which the imdn state has reached the specified state and the time at which they
+ * did.
  * @param message #LinphoneChatMessage object. @notnil
  * @param state The LinphoneChatMessageState the imdn have reached (only use LinphoneChatMessageStateDelivered,
  * LinphoneChatMessageStateDeliveredToUser, LinphoneChatMessageStateDisplayed and LinphoneChatMessageStateNotDelivered)
  * @return The list of participants. \bctbx_list{LinphoneParticipantImdnState} @tobefreed @notnil
  */
-LINPHONE_PUBLIC bctbx_list_t *linphone_chat_message_get_participants_by_imdn_state (
-	const LinphoneChatMessage *message,
-	LinphoneChatMessageState state
-);
+LINPHONE_PUBLIC bctbx_list_t *linphone_chat_message_get_participants_by_imdn_state(const LinphoneChatMessage *message,
+                                                                                   LinphoneChatMessageState state);
 
 /**
  * Gets the callId accociated with the message
@@ -458,13 +461,39 @@ LINPHONE_PUBLIC bctbx_list_t *linphone_chat_message_get_participants_by_imdn_sta
  * @return the call Id @notnil
  */
 LINPHONE_PUBLIC const char *linphone_chat_message_get_call_id(const LinphoneChatMessage *message);
-	
+
+/**
+ * Gets the list of reactions received for this chat message.
+ * Warning: list is ordered by content of reaction message, not by received timestamp!
+ * @param message #LinphoneChatMessage object. @notnil
+ * @return The sorted list of reaction if any. \bctbx_list{LinphoneChatMessageReaction} @maybenil @tobefreed
+ */
+LINPHONE_PUBLIC bctbx_list_t *linphone_chat_message_get_reactions(const LinphoneChatMessage *msg);
+
+/**
+ * Returns our own reaction for a given chat message, if any.
+ * @param message #LinphoneChatMessage object. @notnil
+ * @return Our own #LinphoneChatMessageReaction for that message if any, NULL otherwise. @maybenil
+ */
+LINPHONE_PUBLIC const LinphoneChatMessageReaction *
+linphone_chat_message_get_own_reaction(const LinphoneChatMessage *msg);
+
 /**
  * Returns wether the chat message has a conference invitation content or not.
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if it has one, FALSE otherwise.
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_has_conference_invitation_content (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_has_conference_invitation_content(const LinphoneChatMessage *message);
+
+/**
+ * Creates a emoji reaction for the given chat mesage.
+ * To send it, use linphone_chat_message_reaction_send().
+ * @param message the message you want to react on @notnil
+ * @param utf8_reaction the emoji character(s) as UTF-8. @notnil
+ * @return a #LinphoneChatMessageReaction object. @notnil
+ */
+LINPHONE_PUBLIC LinphoneChatMessageReaction *linphone_chat_message_create_reaction(LinphoneChatMessage *message,
+                                                                                   const char *utf8_reaction);
 
 /************ */
 /* DEPRECATED */
@@ -474,9 +503,10 @@ LINPHONE_PUBLIC bool_t linphone_chat_message_has_conference_invitation_content (
  * Returns wether the chat message has a text content or not.
  * @param message #LinphoneChatMessage object. @notnil
  * @return TRUE if it has one, FALSE otherwise.
- * @deprecated 27/10/2020. Check if linphone_chat_message_get_contents() contains a #LinphoneContent for which it's content type is PlainText.
+ * @deprecated 27/10/2020. Check if linphone_chat_message_get_contents() contains a #LinphoneContent for which it's
+ * content type is PlainText.
  */
-LINPHONE_PUBLIC bool_t linphone_chat_message_has_text_content (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC bool_t linphone_chat_message_has_text_content(const LinphoneChatMessage *message);
 
 /**
  * Get text part of this message
@@ -485,7 +515,7 @@ LINPHONE_PUBLIC bool_t linphone_chat_message_has_text_content (const LinphoneCha
  * @deprecated 07/11/2017 use linphone_chat_message_get_utf8_text() instead
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *linphone_chat_message_get_text (const LinphoneChatMessage* message);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *linphone_chat_message_get_text(const LinphoneChatMessage *message);
 
 /**
  * Get the path to the file to read from or write to during the file transfer.
@@ -494,23 +524,21 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *linphone_chat_message_get_text (
  * @deprecated 12/07/2018 use linphone_content_get_file_path() instead.
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *linphone_chat_message_get_file_transfer_filepath (const LinphoneChatMessage *message);
-
+LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *
+linphone_chat_message_get_file_transfer_filepath(const LinphoneChatMessage *message);
 
 /**
  * Start the download of the file from remote server
  *
  * @param message #LinphoneChatMessage object. @notnil
- * @param status_cb #LinphoneChatMessageStateChangeCb status callback invoked when file is downloaded or could not be downloaded
+ * @param status_cb #LinphoneChatMessageStateChangeCb status callback invoked when file is downloaded or could not be
+ * downloaded
  * @param user_data user data
  * @deprecated 21/09/2017 Use linphone_chat_message_download_file() instead.
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_start_file_download (
-	LinphoneChatMessage *message,
-	LinphoneChatMessageStateChangedCb status_cb,
-	void *user_data
-);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_start_file_download(
+    LinphoneChatMessage *message, LinphoneChatMessageStateChangedCb status_cb, void *user_data);
 
 /**
  * Start the download of the file referenced in a #LinphoneChatMessage from remote server.
@@ -518,7 +546,7 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_start_file_downlo
  * @deprecated 12/07/2018 Use linphone_chat_message_download_content() instead
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED bool_t linphone_chat_message_download_file (LinphoneChatMessage *message);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED bool_t linphone_chat_message_download_file(LinphoneChatMessage *message);
 
 /**
  * Resend a chat message if it is in the 'not delivered' state for whatever reason.
@@ -526,7 +554,7 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED bool_t linphone_chat_message_download_file (
  * @deprecated 13/10/2017 Use linphone_chat_message_send instead.
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_resend (LinphoneChatMessage *message);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_resend(LinphoneChatMessage *message);
 
 /**
  * Set the path to the file to read from or write to during the file transfer.
@@ -535,7 +563,8 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_resend (LinphoneC
  * @deprecated 12/07/2018 use linphone_content_set_file_path() instead.
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_set_file_transfer_filepath (LinphoneChatMessage *message, const char *filepath);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_set_file_transfer_filepath(LinphoneChatMessage *message,
+                                                                                          const char *filepath);
 
 /**
  * Get the #LinphoneChatMessageCbs object associated with the LinphoneChatMessage.
@@ -544,7 +573,8 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_set_file_transfer
  * @deprecated 19/02/2019
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneChatMessageCbs *linphone_chat_message_get_callbacks (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneChatMessageCbs *
+linphone_chat_message_get_callbacks(const LinphoneChatMessage *message);
 
 /**
  * Set a chat message text to be sent by linphone_chat_room_send_message()
@@ -554,7 +584,7 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneChatMessageCbs *linphone_chat_messag
  * @deprecated 01/07/2020. Use linphone_chat_message_set_utf8_text() instead.
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED int linphone_chat_message_set_text(LinphoneChatMessage *message , const char* text);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED int linphone_chat_message_set_text(LinphoneChatMessage *message, const char *text);
 
 /**
  * Gets the text content if available as a string
@@ -562,7 +592,8 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED int linphone_chat_message_set_text(LinphoneC
  * @return the #LinphoneContent buffer if available in System Locale, null otherwise. @maybenil
  * @deprecated 01/07/2020. Use linphone_chat_message_get_utf8_text() instead.
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *linphone_chat_message_get_text_content (const LinphoneChatMessage *message );
+LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *
+linphone_chat_message_get_text_content(const LinphoneChatMessage *message);
 
 /**
  * Creates a #LinphoneContent of type PlainText with the given text as body.
@@ -570,23 +601,26 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED const char *linphone_chat_message_get_text_c
  * @param text The text in System Locale to add to the message. @notnil
  * @deprecated 01/07/2020. Use linphone_chat_message_add_utf8_text_content() instead.
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_add_text_content (LinphoneChatMessage *message, const char *text);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_chat_message_add_text_content(LinphoneChatMessage *message,
+                                                                                const char *text);
 
 /**
  * Return whether or not a chat message is a file transfer.
  * @param message #LinphoneChatMessage object @notnil
  * @return Whether or not the message is a file transfer
- * @deprecated 06/07/2020 check if linphone_chat_message_get_contents() contains a #LinphoneContent for which linphone_content_is_file_transfer() returns TRUE.
+ * @deprecated 06/07/2020 check if linphone_chat_message_get_contents() contains a #LinphoneContent for which
+ * linphone_content_is_file_transfer() returns TRUE.
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED bool_t linphone_chat_message_is_file_transfer (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED bool_t linphone_chat_message_is_file_transfer(const LinphoneChatMessage *message);
 
 /**
  * Return whether or not a chat message is a text.
  * @param message #LinphoneChatMessage object. @notnil
  * @return Whether or not the message is a text
- * @deprecated 06/07/2020 check if linphone_chat_message_get_contents() contains a #LinphoneContent with a PlainText content type.
+ * @deprecated 06/07/2020 check if linphone_chat_message_get_contents() contains a #LinphoneContent with a PlainText
+ * content type.
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED bool_t linphone_chat_message_is_text (const LinphoneChatMessage *message);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED bool_t linphone_chat_message_is_text(const LinphoneChatMessage *message);
 
 /**
  * @}
