@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of Liblinphone 
+ * This file is part of Liblinphone
  * (see https://gitlab.linphone.org/BC/public/liblinphone).
  *
  * This program is free software: you can redistribute it and/or modify
@@ -21,9 +21,9 @@
 #ifndef LINPHONE_FRIEND_H_
 #define LINPHONE_FRIEND_H_
 
-#include "linphone/types.h"
-#include "linphone/sipsetup.h"
 #include "linphone/callbacks.h"
+#include "linphone/sipsetup.h"
+#include "linphone/types.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -40,15 +40,16 @@ extern "C" {
  * @param address the #LinphoneAddress to set @maybenil
  * return 0 if successful, -1 otherwise
  */
-LINPHONE_PUBLIC LinphoneStatus linphone_friend_set_address(LinphoneFriend *fr, const LinphoneAddress* address);
+LINPHONE_PUBLIC LinphoneStatus linphone_friend_set_address(LinphoneFriend *fr, const LinphoneAddress *address);
 
 /**
  * Get address of this friend.
- * @note the #LinphoneAddress object returned is hold by the LinphoneFriend, however calling several time this function may return different objects.
+ * @note the #LinphoneAddress object returned is hold by the LinphoneFriend, however calling several time this function
+ * may return different objects.
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return the #LinphoneAddress. @maybenil
  */
-LINPHONE_PUBLIC const LinphoneAddress * linphone_friend_get_address(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC const LinphoneAddress *linphone_friend_get_address(const LinphoneFriend *linphone_friend);
 
 /**
  * Adds an address in this friend
@@ -62,7 +63,7 @@ LINPHONE_PUBLIC void linphone_friend_add_address(LinphoneFriend *linphone_friend
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return A list of #LinphoneAddress. \bctbx_list{LinphoneAddress} @maybenil
  */
-LINPHONE_PUBLIC const bctbx_list_t* linphone_friend_get_addresses(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC const bctbx_list_t *linphone_friend_get_addresses(const LinphoneFriend *linphone_friend);
 
 /**
  * Removes an address in this friend
@@ -83,21 +84,22 @@ LINPHONE_PUBLIC void linphone_friend_add_phone_number(LinphoneFriend *linphone_f
  * @param linphone_friend #LinphoneFriend object @notnil
  * @param phone_number the #LinphoneFriendPhoneNumber to add @notnil
  */
-LINPHONE_PUBLIC void linphone_friend_add_phone_number_with_label(LinphoneFriend *linphone_friend, LinphoneFriendPhoneNumber *phone_number);
+LINPHONE_PUBLIC void linphone_friend_add_phone_number_with_label(LinphoneFriend *linphone_friend,
+                                                                 LinphoneFriendPhoneNumber *phone_number);
 
 /**
  * Returns a list of phone numbers for this friend
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return A list of phone numbers as string. \bctbx_list{char *} @maybenil @tobefreed
  */
-LINPHONE_PUBLIC bctbx_list_t* linphone_friend_get_phone_numbers(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC bctbx_list_t *linphone_friend_get_phone_numbers(const LinphoneFriend *linphone_friend);
 
 /**
  * Returns a list of #LinphoneFriendPhoneNumber for this friend
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return A list of phone numbers as string. \bctbx_list{LinphoneFriendPhoneNumber} @maybenil @tobefreed
  */
-LINPHONE_PUBLIC bctbx_list_t* linphone_friend_get_phone_numbers_with_label(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC bctbx_list_t *linphone_friend_get_phone_numbers_with_label(const LinphoneFriend *linphone_friend);
 
 /**
  * Returns whether a friend contains the given phone number
@@ -105,7 +107,8 @@ LINPHONE_PUBLIC bctbx_list_t* linphone_friend_get_phone_numbers_with_label(const
  * @param phone_number the phone number to search for @notnil
  * @return TRUE if found, FALSE otherwise
  */
-LINPHONE_PUBLIC bool_t linphone_friend_has_phone_number(const LinphoneFriend *linphone_friend, const char *phone_number);
+LINPHONE_PUBLIC bool_t linphone_friend_has_phone_number(const LinphoneFriend *linphone_friend,
+                                                        const char *phone_number);
 
 /**
  * Removes a phone number in this friend
@@ -119,7 +122,8 @@ LINPHONE_PUBLIC void linphone_friend_remove_phone_number(LinphoneFriend *linphon
  * @param linphone_friend #LinphoneFriend object @notnil
  * @param phone_number the #LinphoneFriendPhoneNumber to remove @notnil
  */
-LINPHONE_PUBLIC void linphone_friend_remove_phone_number_with_label(LinphoneFriend *linphone_friend, const LinphoneFriendPhoneNumber *phone_number);
+LINPHONE_PUBLIC void linphone_friend_remove_phone_number_with_label(LinphoneFriend *linphone_friend,
+                                                                    const LinphoneFriendPhoneNumber *phone_number);
 
 /**
  * Set the display name for this friend
@@ -134,7 +138,7 @@ LINPHONE_PUBLIC LinphoneStatus linphone_friend_set_name(LinphoneFriend *linphone
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return The display name of this friend. @maybenil
  */
-LINPHONE_PUBLIC const char * linphone_friend_get_name(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC const char *linphone_friend_get_name(const LinphoneFriend *linphone_friend);
 
 /**
  * get subscription flag value
@@ -150,7 +154,7 @@ LINPHONE_PUBLIC bool_t linphone_friend_subscribes_enabled(const LinphoneFriend *
  * @param enable if TRUE this friend will receive subscription message
  * @return 0
  */
-LINPHONE_PUBLIC	LinphoneStatus linphone_friend_enable_subscribes(LinphoneFriend *fr, bool_t enable);
+LINPHONE_PUBLIC LinphoneStatus linphone_friend_enable_subscribes(LinphoneFriend *fr, bool_t enable);
 #define linphone_friend_send_subscribe linphone_friend_enable_subscribes
 
 /**
@@ -159,7 +163,8 @@ LINPHONE_PUBLIC	LinphoneStatus linphone_friend_enable_subscribes(LinphoneFriend
  * @param policy #LinphoneSubscribePolicy policy to apply.
  * @return 0
  */
-LINPHONE_PUBLIC LinphoneStatus linphone_friend_set_inc_subscribe_policy(LinphoneFriend *fr, LinphoneSubscribePolicy policy);
+LINPHONE_PUBLIC LinphoneStatus linphone_friend_set_inc_subscribe_policy(LinphoneFriend *fr,
+                                                                        LinphoneSubscribePolicy policy);
 
 /**
  * get current subscription policy for this #LinphoneFriend
@@ -177,14 +182,14 @@ LINPHONE_PUBLIC LinphoneSubscribePolicy linphone_friend_get_inc_subscribe_policy
  * Once the modifications are done, then the application must call
  * linphone_friend_done() to commit the changes.
  * @param linphone_friend #LinphoneFriend object @notnil
-**/
-LINPHONE_PUBLIC	void linphone_friend_edit(LinphoneFriend *linphone_friend);
+ **/
+LINPHONE_PUBLIC void linphone_friend_edit(LinphoneFriend *linphone_friend);
 
 /**
  * Commits modification made to the friend configuration.
  * @param linphone_friend #LinphoneFriend object @notnil
-**/
-LINPHONE_PUBLIC	void linphone_friend_done(LinphoneFriend *linphone_friend);
+ **/
+LINPHONE_PUBLIC void linphone_friend_done(LinphoneFriend *linphone_friend);
 
 /**
  * Get subscription state of a friend
@@ -194,33 +199,40 @@ LINPHONE_PUBLIC	void linphone_friend_done(LinphoneFriend *linphone_friend);
 LINPHONE_PUBLIC LinphoneSubscriptionState linphone_friend_get_subscription_state(const LinphoneFriend *linphone_friend);
 
 /**
- * Get the presence model of a friend
+ * Get the presence model of a friend. If a friend has more than one SIP address and phone number,
+ * this method will return the most recent presence model using linphone_presence_model_get_timestamp().
  * @param linphone_friend A #LinphoneFriend object @notnil
- * @return A #LinphonePresenceModel object, or NULL if the friend do not have presence information (in which case he is considered offline). @maybenil
+ * @return A #LinphonePresenceModel object, or NULL if the friend do not have presence information (in which case he is
+ * considered offline). @maybenil
  */
-LINPHONE_PUBLIC const LinphonePresenceModel * linphone_friend_get_presence_model(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC const LinphonePresenceModel *linphone_friend_get_presence_model(const LinphoneFriend *linphone_friend);
 
 /**
  * Get the consolidated presence of a friend.
+ * It will return the "most open" presence found if more than one presence model are found.
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return The #LinphoneConsolidatedPresence of the friend
  */
-LINPHONE_PUBLIC LinphoneConsolidatedPresence linphone_friend_get_consolidated_presence(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC LinphoneConsolidatedPresence
+linphone_friend_get_consolidated_presence(const LinphoneFriend *linphone_friend);
 
 /**
  * Get the presence model for a specific SIP URI or phone number of a friend
  * @param linphone_friend A #LinphoneFriend object @notnil
  * @param uri_or_tel The SIP URI or phone number for which to get the presence model @notnil
- * @return A #LinphonePresenceModel object, or NULL if the friend do not have presence information for this SIP URI or phone number. @maybenil
+ * @return A #LinphonePresenceModel object, or NULL if the friend do not have presence information for this SIP URI or
+ * phone number. @maybenil
  */
-LINPHONE_PUBLIC const LinphonePresenceModel * linphone_friend_get_presence_model_for_uri_or_tel(const LinphoneFriend *linphone_friend, const char *uri_or_tel);
+LINPHONE_PUBLIC const LinphonePresenceModel *
+linphone_friend_get_presence_model_for_uri_or_tel(const LinphoneFriend *linphone_friend, const char *uri_or_tel);
 
 /**
  * Set the presence model of a friend
  * @param linphone_friend A #LinphoneFriend object @notnil
  * @param presence The #LinphonePresenceModel object to set for the friend @maybenil
  */
-LINPHONE_PUBLIC void linphone_friend_set_presence_model(LinphoneFriend *linphone_friend, LinphonePresenceModel *presence);
+LINPHONE_PUBLIC void linphone_friend_set_presence_model(LinphoneFriend *linphone_friend,
+                                                        LinphonePresenceModel *presence);
 
 /**
  * Set the presence model for a specific SIP URI or phone number of a friend
@@ -228,7 +240,9 @@ LINPHONE_PUBLIC void linphone_friend_set_presence_model(LinphoneFriend *linphone
  * @param uri_or_tel The SIP URI or phone number for which to set the presence model @notnil
  * @param presence The #LinphonePresenceModel object to set @maybenil
  */
-LINPHONE_PUBLIC void linphone_friend_set_presence_model_for_uri_or_tel(LinphoneFriend *linphone_friend, const char *uri_or_tel, LinphonePresenceModel *presence);
+LINPHONE_PUBLIC void linphone_friend_set_presence_model_for_uri_or_tel(LinphoneFriend *linphone_friend,
+                                                                       const char *uri_or_tel,
+                                                                       LinphonePresenceModel *presence);
 
 /**
  * Tells whether we already received presence information for a friend.
@@ -241,50 +255,50 @@ LINPHONE_PUBLIC bool_t linphone_friend_is_presence_received(const LinphoneFriend
  * Store user pointer to friend object.
  * @param linphone_friend A #LinphoneFriend object @notnil
  * @param user_data the user data to store. @maybenil
-**/
+ **/
 LINPHONE_PUBLIC void linphone_friend_set_user_data(LinphoneFriend *linphone_friend, void *user_data);
 
 /**
  * Retrieve user data associated with friend.
  * @param linphone_friend A #LinphoneFriend object @notnil
  * @return the user data pointer. @maybenil
-**/
-LINPHONE_PUBLIC void* linphone_friend_get_user_data(const LinphoneFriend *linphone_friend);
+ **/
+LINPHONE_PUBLIC void *linphone_friend_get_user_data(const LinphoneFriend *linphone_friend);
 
-LINPHONE_PUBLIC BuddyInfo * linphone_friend_get_info(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC BuddyInfo *linphone_friend_get_info(const LinphoneFriend *linphone_friend);
 
 /**
  * Set the reference key of a friend.
  * @param linphone_friend #LinphoneFriend object. @notnil
  * @param key The reference key to use for the friend. @maybenil
-**/
+ **/
 LINPHONE_PUBLIC void linphone_friend_set_ref_key(LinphoneFriend *linphone_friend, const char *key);
 
 /**
  * Get the reference key of a friend.
  * @param linphone_friend #LinphoneFriend object. @notnil
  * @return The reference key of the friend. @maybenil
-**/
+ **/
 LINPHONE_PUBLIC const char *linphone_friend_get_ref_key(const LinphoneFriend *linphone_friend);
 
 /**
  * Check that the given friend is in a friend list.
  * @param linphone_friend #LinphoneFriend object. @notnil
  * @return TRUE if the friend is in a friend list, FALSE otherwise.
-**/
+ **/
 LINPHONE_PUBLIC bool_t linphone_friend_in_list(const LinphoneFriend *linphone_friend);
 
 /**
  * Acquire a reference to the linphone friend.
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return The same #LinphoneFriend object @notnil
-**/
-LINPHONE_PUBLIC LinphoneFriend * linphone_friend_ref(LinphoneFriend *linphone_friend);
+ **/
+LINPHONE_PUBLIC LinphoneFriend *linphone_friend_ref(LinphoneFriend *linphone_friend);
 
 /**
  * Release a reference to the linphone friend.
  * @param linphone_friend #LinphoneFriend object @notnil
-**/
+ **/
 LINPHONE_PUBLIC void linphone_friend_unref(LinphoneFriend *linphone_friend);
 
 /**
@@ -299,7 +313,7 @@ LINPHONE_PUBLIC LinphoneCore *linphone_friend_get_core(const LinphoneFriend *lin
  * @param linphone_friend #LinphoneFriend object @notnil
  * @return the #LinphoneVcard or NULL. @maybenil
  */
-LINPHONE_PUBLIC LinphoneVcard* linphone_friend_get_vcard(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC LinphoneVcard *linphone_friend_get_vcard(const LinphoneFriend *linphone_friend);
 
 /**
  * Binds a vCard object to a friend
@@ -309,10 +323,12 @@ LINPHONE_PUBLIC LinphoneVcard* linphone_friend_get_vcard(const LinphoneFriend *l
 LINPHONE_PUBLIC void linphone_friend_set_vcard(LinphoneFriend *linphone_friend, LinphoneVcard *vcard);
 
 /**
- * Creates a vCard object associated to this friend if there isn't one yet and if the full name is available, either by the parameter or the one in the friend's SIP URI
+ * Creates a vCard object associated to this friend if there isn't one yet and if the full name is available, either by
+ * the parameter or the one in the friend's SIP URI
  * @param linphone_friend #LinphoneFriend object @notnil
  * @param name The full name of the friend or NULL to use the one from the friend's SIP URI @maybenil
- * @return TRUE if the vCard has been created, FALSE if it wasn't possible (for exemple if name and the friend's SIP URI are null or if the friend's SIP URI doesn't have a display name), or if there is already one vcard
+ * @return TRUE if the vCard has been created, FALSE if it wasn't possible (for exemple if name and the friend's SIP URI
+ * are null or if the friend's SIP URI doesn't have a display name), or if there is already one vcard
  */
 LINPHONE_PUBLIC bool_t linphone_friend_create_vcard(LinphoneFriend *linphone_friend, const char *name);
 
@@ -322,7 +338,7 @@ LINPHONE_PUBLIC bool_t linphone_friend_create_vcard(LinphoneFriend *linphone_fri
  * @return a new #LinphoneFriend which has its vCard attribute initialized from the given vCard.
  * This can be get by linphone_friend_get_vcard(). @maybenil
  */
-LINPHONE_PUBLIC	LinphoneFriend *linphone_friend_new_from_vcard(LinphoneVcard *vcard);
+LINPHONE_PUBLIC LinphoneFriend *linphone_friend_new_from_vcard(LinphoneVcard *vcard);
 
 /**
  * Saves a friend either in database if configured, otherwise in linphonerc
@@ -344,7 +360,8 @@ LINPHONE_PUBLIC int linphone_friend_get_capabilities(const LinphoneFriend *linph
  * @param capability #LinphoneFriendCapability object
  * @return whether or not a friend has a capbility
  */
-LINPHONE_PUBLIC bool_t linphone_friend_has_capability(const LinphoneFriend *linphone_friend, const LinphoneFriendCapability capability);
+LINPHONE_PUBLIC bool_t linphone_friend_has_capability(const LinphoneFriend *linphone_friend,
+                                                      const LinphoneFriendCapability capability);
 
 /**
  * Returns whether or not a friend has a capbility with a given version.
@@ -353,7 +370,9 @@ LINPHONE_PUBLIC bool_t linphone_friend_has_capability(const LinphoneFriend *linp
  * @param version the version to test
  * @return whether or not a friend has a capbility with a given version or -1.0 if friend has not capability.
  */
-LINPHONE_PUBLIC bool_t linphone_friend_has_capability_with_version(const LinphoneFriend *linphone_friend, const LinphoneFriendCapability capability, float version);
+LINPHONE_PUBLIC bool_t linphone_friend_has_capability_with_version(const LinphoneFriend *linphone_friend,
+                                                                   const LinphoneFriendCapability capability,
+                                                                   float version);
 
 /**
  * Returns whether or not a friend has a capbility with a given version or more.
@@ -362,7 +381,9 @@ LINPHONE_PUBLIC bool_t linphone_friend_has_capability_with_version(const Linphon
  * @param version the version to test
  * @return whether or not a friend has a capbility with a given version or more.
  */
-LINPHONE_PUBLIC bool_t linphone_friend_has_capability_with_version_or_more(const LinphoneFriend *linphone_friend, const LinphoneFriendCapability capability, float version);
+LINPHONE_PUBLIC bool_t linphone_friend_has_capability_with_version_or_more(const LinphoneFriend *linphone_friend,
+                                                                           const LinphoneFriendCapability capability,
+                                                                           float version);
 
 /**
  * Returns the version of a friend's capbility.
@@ -370,7 +391,8 @@ LINPHONE_PUBLIC bool_t linphone_friend_has_capability_with_version_or_more(const
  * @param capability #LinphoneFriendCapability object
  * @return the version of a friend's capbility.
  */
-LINPHONE_PUBLIC float linphone_friend_get_capability_version(const LinphoneFriend *linphone_friend, const LinphoneFriendCapability capability);
+LINPHONE_PUBLIC float linphone_friend_get_capability_version(const LinphoneFriend *linphone_friend,
+                                                             const LinphoneFriendCapability capability);
 
 /**
  * Removes a friend from it's friend list and from the rc if exists
@@ -390,7 +412,7 @@ LINPHONE_PUBLIC void linphone_friend_set_photo(LinphoneFriend *linphone_friend,
  * @param linphone_friend the #LinphoneFriend object.
  * @return the picture URI set if any, NULL otherwise. @maybenil
  */
-LINPHONE_PUBLIC const char * linphone_friend_get_photo(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC const char *linphone_friend_get_photo(const LinphoneFriend *linphone_friend);
 
 /**
  * Sets if the friend is a user's favorite or important contact.
@@ -418,7 +440,7 @@ LINPHONE_PUBLIC void linphone_friend_set_native_uri(LinphoneFriend *linphone_fri
  * @param linphone_friend the #LinphoneFriend object.
  * @return the native URI set if any, NULL otherwise. @maybenil
  */
-LINPHONE_PUBLIC const char * linphone_friend_get_native_uri(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC const char *linphone_friend_get_native_uri(const LinphoneFriend *linphone_friend);
 
 /**
  * Sets the contact's organization.
@@ -429,12 +451,28 @@ LINPHONE_PUBLIC const char * linphone_friend_get_native_uri(const LinphoneFriend
 LINPHONE_PUBLIC void linphone_friend_set_organization(LinphoneFriend *linphone_friend, const char *organization);
 
 /**
- * Gets the contact's organization from it's vCard. 
+ * Gets the contact's organization from it's vCard.
  * It's a shortcut to linphone_friend_get_vcard() and linphone_vcard_get_organization().
  * @param linphone_friend the #LinphoneFriend object.
  * @return the organization set if any & vCard is available, NULL otherwise. @maybenil
  */
-LINPHONE_PUBLIC const char * linphone_friend_get_organization(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC const char *linphone_friend_get_organization(const LinphoneFriend *linphone_friend);
+
+/**
+ * Sets the contact's job title.
+ * It's a shortcut to linphone_friend_get_vcard() and linphone_vcard_set_job_title().
+ * @param linphone_friend the #LinphoneFriend object.
+ * @param job_title the job title to store in Friend's vCard. @maybenil
+ */
+LINPHONE_PUBLIC void linphone_friend_set_job_title(LinphoneFriend *linphone_friend, const char *job_title);
+
+/**
+ * Gets the contact's job title from it's vCard.
+ * It's a shortcut to linphone_friend_get_vcard() and linphone_vcard_get_job_title().
+ * @param linphone_friend the #LinphoneFriend object.
+ * @return the job_title set if any & vCard is available, NULL otherwise. @maybenil
+ */
+LINPHONE_PUBLIC const char *linphone_friend_get_job_title(const LinphoneFriend *linphone_friend);
 
 /************ */
 /* Friend CBS */
@@ -492,15 +530,17 @@ LINPHONE_PUBLIC void linphone_friend_cbs_set_user_data(LinphoneFriendCbs *cbs, v
  * Get the presence received callback.
  * @param cbs #LinphoneFriendCbs object. @notnil
  * @return The current presence received callback.
-**/
-LINPHONE_PUBLIC LinphoneFriendCbsPresenceReceivedCb linphone_friend_cbs_get_presence_received(const LinphoneFriendCbs *cbs);
+ **/
+LINPHONE_PUBLIC LinphoneFriendCbsPresenceReceivedCb
+linphone_friend_cbs_get_presence_received(const LinphoneFriendCbs *cbs);
 
 /**
  * Set the presence received callback.
  * @param cbs #LinphoneFriendCbs object. @notnil
  * @param cb The presence received callback to be used.
-**/
-LINPHONE_PUBLIC void linphone_friend_cbs_set_presence_received(LinphoneFriendCbs *cbs, LinphoneFriendCbsPresenceReceivedCb cb);
+ **/
+LINPHONE_PUBLIC void linphone_friend_cbs_set_presence_received(LinphoneFriendCbs *cbs,
+                                                               LinphoneFriendCbsPresenceReceivedCb cb);
 
 /************ */
 /* DEPRECATED */
@@ -512,7 +552,7 @@ LINPHONE_PUBLIC void linphone_friend_cbs_set_presence_received(LinphoneFriendCbs
  * @deprecated 03/02/2016 use #linphone_core_create_friend() instead
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneFriend * linphone_friend_new(void);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneFriend *linphone_friend_new(void);
 
 /**
  * Contructor same as linphone_friend_new() + linphone_friend_set_address()
@@ -521,7 +561,7 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneFriend * linphone_friend_new(void);
  * @deprecated 03/02/2016 use #linphone_core_create_friend_with_address() instead
  * @donotwrap
  */
-LINPHONE_PUBLIC	LINPHONE_DEPRECATED LinphoneFriend *linphone_friend_new_with_address(const char *addr);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneFriend *linphone_friend_new_with_address(const char *addr);
 
 /**
  * Destroy a LinphoneFriend.
@@ -538,7 +578,8 @@ LINPHONE_PUBLIC LINPHONE_DEPRECATED void linphone_friend_destroy(LinphoneFriend
  * @deprecated 19/06/2013 Use linphone_friend_get_presence_model() instead
  * @donotwrap
  */
-LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneOnlineStatus linphone_friend_get_status(const LinphoneFriend *linphone_friend);
+LINPHONE_PUBLIC LINPHONE_DEPRECATED LinphoneOnlineStatus
+linphone_friend_get_status(const LinphoneFriend *linphone_friend);
 
 /**
  * @}
